#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_MEANOF_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_MEANOF_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/simd/meanof.hpp>

#endif
